@@ -9,10 +9,10 @@ test_that('test_dir()', {
         "test-basic.r", "test-basic.r", "test-empty.r", "test-empty.r",
         "test-errors.r", "test-errors.r", "test-errors.r", "test-errors.r",
         "test-errors.r", "test-failures.r", "test-failures.r", "test-failures.r",
-        "test-helper.r"),
+        "test-helper.r", "test-skip.r"),
       context = c("Basic", "Basic", "Basic", "Basic",
         "Basic", "empty", "empty", "error", "error", "error", "error",
-        "error", "failures", "failures", "failures", "helper"),
+        "error", "failures", "failures", "failures", "helper", "skip"),
       test = c("logical tests act as expected",
         "logical tests ignore attributes", "equality holds",
         "can't access variables from other tests 2",
@@ -20,12 +20,14 @@ test_that('test_dir()', {
         "empty test with error",
         "simple", "after one success", "after one failure", "in the test",
         "in expect_error", "just one failure", "one failure on two",
-        "no failure", "helper test"),
-      nb = c(2L, 2L, 2L, 0L, 1L, 0L, 0L, 0L, 1L, 1L, 0L, 1L, 1L, 2L, 2L, 1L),
-      failed = c(0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 1L, 0L, 0L, 1L, 1L, 0L, 0L),
-      skipped = c(0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L),
+        "no failure", "helper test",
+        "Skips skip"),
+      nb = c(2L, 2L, 2L, 0L, 1L, 0L, 0L, 0L, 1L, 1L, 0L, 1L, 1L, 2L, 2L, 1L, 1L),
+      failed = c(0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 1L, 0L, 0L, 1L, 1L, 0L, 0L, 0L),
+      skipped = c(FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE,
+        FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE),
       error = c(FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, TRUE, TRUE, TRUE,
-        TRUE, FALSE, FALSE, FALSE, FALSE, FALSE),
+        TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE),
       stringsAsFactors = FALSE)
 
   df$user <- df$system  <- df$real <- NULL
